@@ -19,7 +19,8 @@
 #
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
 #'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
-#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
+#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} & \link{visFocus} & \link{visFit} for animation within shiny,
+#'\link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
 #'
 #' @export
 visConfigure <- function(graph,
@@ -28,14 +29,22 @@ visConfigure <- function(graph,
                          container = NULL,
                          showButton = NULL){
 
+  if(!any(class(graph) %in% c("visNetwork", "visNetwork_Proxy"))){
+    stop("graph must be a visNetwork or a visNetworkProxy object")
+  }
+  
   configure <- list()
   configure$enabled <- enabled
   configure$filter <- filter
   configure$container <- container
   configure$showButton <- showButton
   
-  graph$x$options$configure <- configure
-
+  if(any(class(graph) %in% "visNetwork_Proxy")){
+    options <- list(configure = configure)
+    data <- list(id = graph$id, options = options)
+    graph$session$sendCustomMessage("Options",data)
+  }else{
+    graph$x$options$configure <- configure
+  }
   graph
-
 }
