@@ -83,8 +83,8 @@
 #'
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
 #'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
-#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
-#'
+#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} & \link{visFocus} & \link{visFit} for animation within shiny,
+#'\link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
 #' 
 #' @examples
 #' nodes <- data.frame(id = 1:3)
@@ -136,6 +136,10 @@ visEdges <- function(graph,
                      shadow = NULL, 
                      scaling = NULL){
 
+  if(!any(class(graph) %in% c("visNetwork", "visNetwork_Proxy"))){
+    stop("graph must be a visNetwork or a visNetworkProxy object")
+  }
+  
   edges <- list()
 
   edges$title <- title
@@ -165,7 +169,12 @@ visEdges <- function(graph,
   
   edges$scaling <- scaling
   
-  graph$x$options$edges <- mergeLists(graph$x$options$edges, edges)
-
+  if(any(class(graph) %in% "visNetwork_Proxy")){
+    options <- list(edges = edges)
+    data <- list(id = graph$id, options = options)
+    graph$session$sendCustomMessage("Options",data)
+  }else{
+    graph$x$options$edges <- mergeLists(graph$x$options$edges, edges)
+  }
   graph
 }
