@@ -21,8 +21,8 @@
 #'  
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
 #'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
-#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
-#'
+#'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} & \link{visFocus} & \link{visFit} for animation within shiny,
+#'\link{visDocumentation}, \link{visEvents}, \link{visConfigure} ...
 #'
 #'@export
 
@@ -31,15 +31,24 @@ visHierarchicalLayout <- function(graph,
                                   levelSeparation = NULL,
                                   direction = NULL,
                                   sortMethod = NULL){
-
+  
+  if(!any(class(graph) %in% c("visNetwork", "visNetwork_Proxy"))){
+    stop("graph must be a visNetwork or a visNetworkProxy object")
+  }
+  
   hierarchicalLayout <- list()
 
   hierarchicalLayout$enabled <- enabled
   hierarchicalLayout$levelSeparation <- levelSeparation
   hierarchicalLayout$direction <- direction
   hierarchicalLayout$sortMethod <- sortMethod
-
-  graph$x$options$layout$hierarchical <- hierarchicalLayout
   
+  if(any(class(graph) %in% "visNetwork_Proxy")){
+    options <- list(layout = list(hierarchical = hierarchicalLayout))
+    data <- list(id = graph$id, options = options)
+    graph$session$sendCustomMessage("Options",data)
+  }else{
+    graph$x$options$layout$hierarchical <- hierarchicalLayout
+  }
   graph
 }
